@@ -177,11 +177,11 @@ const struct operator_data Operator[] = {
 }
 
 CalcEngine::CalcEngine()
-    : only_update_operation_(false)
+    : last_number_(KNumber::Zero)
+    , only_update_operation_(false)
     , percent_mode_(false)
     , repeat_mode_(false)
 {
-    last_number_ = KNumber::Zero;
     error_ = false;
     last_operation_ = FUNC_EQUAL;
 }
